@@ -5,7 +5,7 @@ Created By Murray(m18527) on 2019/9/4 16:48
 from copy import deepcopy
 from .backbone import Backbone, BackboneV1, BackboneV2
 from ..models import Teacher, Student, Class, Classroom, Subject, CourseTableManager, RestTable, News, Notice, Album, \
-    Video, Image, School
+    Video, Image, School, MeetingRoom
 from ..models import CourseTableManagerV1
 from ..models import RestTableV2, CourseTableManagerV2, SemesterV2
 from ..utils.constants import ERROR_PARAMS, SUCCESS, MSG
@@ -377,6 +377,23 @@ class DataClient(object):
         backbone.upload_classrooms(classrooms)
         return True
 
+    @staticmethod
+    def create_meeting_rooms(school_id, meeting_rooms):
+        """
+        同步会议室
+        :param school_id: school_id
+        :param meeting_rooms: Type -> [models.MeetingRoom, models.MeetingRoom]
+        :return:
+        """
+        for room in meeting_rooms:
+            if not isinstance(room, MeetingRoom):
+                logger.error("TypeError: meeting_room must be a models.MeetingRoom instance.")
+                return ERROR_PARAMS, "数据类型不正确。"
+            room.validate()
+        backbone = Backbone(school_id)
+        backbone.upload_meeting_rooms(meeting_rooms)
+        return True
+
     @staticmethod
     def create_news(school_id, news):
         """
