@@ -791,6 +791,26 @@ class BackboneV2(Backbone):
     def upload_semester(self, semester):
         self.create_semester(semester)
 
+    def relate_course_field(self):
+        """
+        将模型Course中的字段通过映射，转换为uid。(班牌后台接口结构)
+        :return:
+        """
+        for course in self.course_manager.courses:
+            course.subject_id = self.subject_map.get(str(course.subject_number), None)
+            if not course.subject_id:
+                print(">>>ERROR: subject_number{}错误，无法找到对应的科目".format(course.subject_number))
+            classroom_id = self.classroom_map.get(str(course.classroom_number), None)
+            if classroom_id:
+                course.classrooms = [classroom_id]
+            course.teacher_id = self.teacher_map.get(course.teacher_number, None)
+            course.class_id = self.class_map.get(course.class_name, None)
+            for student_number in course.student_list:
+                student_id = self.student_map.get(student_number, None)
+                if not student_id:
+                    print(">>>ERROR: student_number{}错误，无法找到对应的学生".format(student_number))
+                course.student_ids.append(student_id)
+
     def upload_course_table(self, course_manager=None, is_active=False, create_manager=True):
         """
         用于client调用，创建课程表
