@@ -2,12 +2,11 @@ from ..models.base import BaseModel
 
 
 class Subject(BaseModel):
-    uid = None
-    name = None  # 必填*
-    number = None  # 必填*
-    school = None
-
     def __init__(self, *args, **kwargs):
+        self.uid = None
+        self.name = None  # 必填*
+        self.number = None  # 必填*
+        self.school = None
         super(Subject, self).__init__(*args, **kwargs)
         self.required_filed = ['name', 'number']
 
