@@ -35,7 +35,9 @@ class Requester(object):
     def _get_method(self, route, params={}, headers={}, timeout=3600):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.get(url=url, headers=headers, params=params)
+        session = requests.session()
+        session.keep_alive = False
+        res = session.get(url=url, headers=headers, params=params)
         try:
             res.raise_for_status()
             data = res.json()
@@ -51,7 +53,9 @@ class Requester(object):
     def _download_method(self, route, file_path, params={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.get(url=url, headers=headers, params=params, timeout=3600)
+        session = requests.session()
+        session.keep_alive = False
+        res = session.get(url=url, headers=headers, params=params, timeout=3600)
         try:
             res.raise_for_status()
             with open(file_path, "wb") as code:
@@ -63,7 +67,9 @@ class Requester(object):
     def _post_method(self, route, data={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.post(url=url, json=data, headers=headers, timeout=3600)
+        session = requests.session()
+        session.keep_alive = False
+        res = session.post(url=url, json=data, headers=headers, timeout=3600)
         try:
             res.raise_for_status()
             print(res.text)
@@ -77,7 +83,9 @@ class Requester(object):
     def _put_method(self, route, data={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.put(url=url, json=data, headers=headers, timeout=3600)
+        session = requests.session()
+        session.keep_alive = False
+        res = session.put(url=url, json=data, headers=headers, timeout=3600)
         try:
             res.raise_for_status()
             print(res.text)
@@ -91,7 +99,9 @@ class Requester(object):
     def _delete_method(self, route, data={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.delete(url=url, json=data, headers=headers, timeout=3600)
+        session = requests.session()
+        session.keep_alive = False
+        res = session.delete(url=url, json=data, headers=headers, timeout=3600)
         try:
             res.raise_for_status()
             print(res.text)
