@@ -261,3 +261,33 @@ class NirvanaRequester(Requester):
         route = "/api/rest_schedule/"
         res = self._get_method(route, params=params)
         return res
+
+    def get_meeting_room_list(self, params={}):
+        route = "/api/meeting_room/"
+        res = self._get_method(route, params=params)
+        return res
+
+    def delete_meeting_room(self, uid):
+        route = "/api/meeting_room/{}/".format(uid)
+        res = self._delete_method(route)
+        return res
+
+    def create_meeting_room(self, data):
+        route = "/api/meeting_room/"
+        res = self._post_method(route, data)
+        return res
+
+    def create_meeting_room_rule(self, data):
+        route = "/api/attendance_meeting/rule/"
+        res = self._post_method(route, data)
+        return res
+
+    def bind_meeting_room_user(self, data):
+        route = "/api/meeting/conventioneer/bind_by_user/"
+        res = self._put_method(route, data)
+        return res
+
+    def unbind_meeting_room_user(self, data):
+        route = "/api/meeting/conventioneer/unbind/"
+        res = self._put_method(route, data)
+        return res
