@@ -24,3 +24,7 @@ SCHOOL_NAME = os.getenv("SCHOOL_NAME", "五楼229环境")
 SCHOOL_SEASON = os.getenv("SCHOOL_SEASON", "winter")
 SEMESTER_NAME = os.getenv("SEMESTER_NAME", "当前学期")
 REST_TABLE_NAME = os.getenv("REST_TABLE_NAME", "全校作息")
+
+# redis
+REDIS_HOST = os.getenv("REDIS_HOST", "10.88.188.229")
+REDIS_PORT = int(os.getenv("REDIS_PORT", 16379))
