@@ -2,7 +2,7 @@
 """
 Created By Murray(m18527) on 2019/9/18 14:14
 """
-from sync.worker import start_all_sync
+from sync.worker import start_table_sync
 
 if __name__ == '__main__':
-    start_all_sync()
+    start_table_sync()
