@@ -12,6 +12,7 @@ class SectionSync(BaseSync):
         now = datetime.datetime.now()
         self.offset = 300
         self.section_map = {}
+        self.name_num = {}
 
     def extract_section(self):
         sql = "SELECT DPCODE1, DPNAME1 FROM BASE_CUSTDEPT ORDER BY DPCODE1"
@@ -19,8 +20,9 @@ class SectionSync(BaseSync):
         rows = self.cur.fetchall()
         for row in rows:
             code, name = row[0], row[1]
-            section = Class(name=name, number=code, school=self.school_id)
+            section = Class(name=name, number=code, grade="高中一年级", school=self.school_id)
             self.section_map[code] = section
+            self.name_num[name] = code
 
     def sync(self):
         self.extract_section()
