@@ -12,7 +12,7 @@ from utils.loggerutils import logging
 logger = logging.getLogger(__name__)
 
 
-def start_all_sync():
+def start_table_sync():
     teacher_sync = TeacherSync()
     teacher_sync.start()
     section_sync = SectionSync()
@@ -34,9 +34,20 @@ def start_all_sync():
     course_sync.classroom_map = classroom_sync.classroom_map
     course_sync.class_name_num = section_sync.name_num
     course_sync.start()
+    # meeting_room_sync = MeetingRoomSync()
+    # meeting_room_sync.start()
+
+
+def start_meeting_sync():
+    teacher_sync = TeacherSync()
+    teacher_sync.start()
+    section_sync = SectionSync()
+    section_sync.start()
+    student_sync = StudentSync()
+    student_sync.start()
     meeting_room_sync = MeetingRoomSync()
     meeting_room_sync.start()
 
 
 if __name__ == '__main__':
-    start_all_sync()
+    start_meeting_sync()
