@@ -111,8 +111,8 @@ class CourseSyncV2(BaseSync2):
                     teacher_number = None
                 course_data = {'name': name, 'number': number, 'subject_number': course_info['subjectID'],
                                "subject_name": subject_name, "class_name": class_name,
-                               'classroom_number': classroom_number, 'is_walking': is_walking,
-                               "teacher_number": teacher_number, "begin_week": 1, "end_week": 30}
+                               'classroom_number': classroom_number, 'is_walking': self.is_walking,
+                               "teacher_number": teacher_number, "begin_week": 1, "end_week": 14}
                 if is_walking:
                     course_data['student_list'] = self.teach_member.get(course_info['qualifiedClassID'], [])
                 else:
@@ -144,7 +144,8 @@ class CourseSyncV2(BaseSync2):
         walking_mode = WalkingModeSet.WALKING if self.is_walking else WalkingModeSet.NOT_WALKING
         course_table = CourseTableManagerV2(name=course_table_name, number=course_table_number,
                                             rest_name=rest_table.name, walking_mode=walking_mode,
-                                            begin_date=begin_date, end_date=end_date, semester_name=semester.name)
+                                            is_walking=self.is_walking, semester_name=semester.name,
+                                            begin_date=begin_date, end_date=end_date)
         for class_num in list(self.class_member.keys()):
             course_table.add_class(class_num)
         used_classroom = self.create_course(response['schedule'])
